@@ -41,6 +41,7 @@ tar_group_select <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
   garbage_collection = targets::tar_option_get("garbage_collection"),
@@ -66,6 +67,7 @@ tar_group_select <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = "group",
     error = error,
     memory = memory,
