@@ -1,7 +1,6 @@
 tar_copy_targets <- function(targets) {
   targets <- unlist(list(targets), recursive = TRUE)
-  msg <- "expected a target list but found non-target objects."
-  assert_targets(targets, msg)
+  targets::tar_assert_target_list(targets)
   lapply(targets, tar_copy_target)
 }
 
@@ -44,3 +43,35 @@ tar_replace_command <- function(target, expr) {
   target$command <- pilot$command
   invisible()
 }
+
+walk_targets <- function(targets, names_quosure, fun, ...) {
+  flat <- unlist(list(targets), recursive = TRUE)
+  targets::tar_assert_target_list(flat)
+  names <- map_chr(flat, ~.x$settings$name)
+  names <- eval_tidyselect(names_quosure, names) %|||% names
+  counter <- counter_init(names = names)
+  recurse_targets(
+    targets = targets,
+    counter = counter,
+    fun = fun,
+    ...
+  )
+}
+
+recurse_targets <- function(targets, counter, fun, ...) {
+  if (is.list(targets) && !inherits(targets, "tar_target")) {
+    lapply(
+      targets,
+      recurse_targets,
+      counter = counter,
+      fun = fun,
+      ...
+    )
+    return()
+  }
+  is_hit <- inherits(targets, "tar_target") &&
+    counter_exists_name(counter, targets$settings$name)
+  if (is_hit) {
+    fun(targets, ...)
+  }
+}
